@@ -2,73 +2,66 @@ use 5.008008;
 use strict;
 use warnings;
 
-{
-	package Ask::Fallback;
-	
-	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.012';
-	
-	use Moo;
-	use Carp qw(croak);
-	use Path::Tiny qw(path);
-	use namespace::autoclean;
-	
-	with 'Ask::API';
-	
-	sub quality {
-		return 1;
-	}
-	
-	sub info {
-		my ($self, %o) = @_;
-		print STDERR "$o{text}\n";
-	}
-	
-	sub warning {
-		my ($self, %o) = @_;
-		print STDERR "WARNING: $o{text}\n";
-	}
-	
-	sub error {
-		my ($self, %o) = @_;
-		print STDERR "ERROR: $o{text}\n";
-	}
-	
-	sub question
-	{
-		my ($self, %o) = @_;
-		exists $o{default} and return $o{default};
-		croak "question (Ask::Fallback) with no default";
-	}
-	
-	sub entry
-	{
-		my ($self, %o) = @_;
-		exists $o{default} and return $o{default};
-		croak "entry (Ask::Fallback) with no default";
-	}
-	
-	sub file_selection
-	{
-		my ($self, %o) = @_;
-		$o{multiple} and exists $o{default} and return map path($_), @{$o{default}};
-		exists $o{default} and return path $o{default};
-		croak "file_selection (Ask::Fallback) with no default";
-	}
-	
-	sub single_choice
-	{
-		my ($self, %o) = @_;
-		exists $o{default} and return $o{default};
-		croak "single_choice (Ask::Fallback) with no default";
-	}
-	
-	sub multiple_choice
-	{
-		my ($self, %o) = @_;
-		exists $o{default} and return @{$o{default}};
-		croak "multiple_choice (Ask::Fallback) with no default";
-	}
+package Ask::Fallback;
+
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.013';
+
+use Moo;
+use Carp qw(croak);
+use Path::Tiny qw(path);
+use namespace::autoclean;
+
+with 'Ask::API';
+
+sub quality {
+	return 1;
+}
+
+sub info {
+	my ( $self, %o ) = @_;
+	print STDERR "$o{text}\n";
+}
+
+sub warning {
+	my ( $self, %o ) = @_;
+	print STDERR "WARNING: $o{text}\n";
+}
+
+sub error {
+	my ( $self, %o ) = @_;
+	print STDERR "ERROR: $o{text}\n";
+}
+
+sub question {
+	my ( $self, %o ) = @_;
+	exists $o{default} and return $o{default};
+	croak "question (Ask::Fallback) with no default";
+}
+
+sub entry {
+	my ( $self, %o ) = @_;
+	exists $o{default} and return $o{default};
+	croak "entry (Ask::Fallback) with no default";
+}
+
+sub file_selection {
+	my ( $self, %o ) = @_;
+	$o{multiple} and exists $o{default} and return map path( $_ ), @{ $o{default} };
+	exists $o{default} and return path $o{default};
+	croak "file_selection (Ask::Fallback) with no default";
+}
+
+sub single_choice {
+	my ( $self, %o ) = @_;
+	exists $o{default} and return $o{default};
+	croak "single_choice (Ask::Fallback) with no default";
+}
+
+sub multiple_choice {
+	my ( $self, %o ) = @_;
+	exists $o{default} and return @{ $o{default} };
+	croak "multiple_choice (Ask::Fallback) with no default";
 }
 
 1;
@@ -126,4 +119,3 @@ the same terms as the Perl 5 programming language system itself.
 THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
